<?php
/* --------------------------------------------------------------
 Country.php 2019-10-24
 Gambio GmbH
 http://www.gambio.de
 Copyright (c) 2019 Gambio GmbH
 Released under the GNU General Public License (Version 2)
 [http://www.gnu.org/licenses/gpl-2.0.html]
 --------------------------------------------------------------
 */

declare(strict_types=1);

namespace Gambio\Core\Configuration\Types;

use Gambio\Core\Configuration\Models\Read\Collections\Options;
use Gambio\Core\Configuration\Repositories\Components\OptionsResolver;
use function strcmp;
use function usort;

/**
 * Class Country
 * @package Gambio\Core\Configuration\Types
 */
class Country implements ConfigurationType
{
    /**
     * Resolves possible options for the current type.
     * This is used to provide selectable list in the ui and can be null.
     *
     * @param OptionsResolver $resolver
     * @param string|null     $value
     *
     * @return Options|null
     */
    public function toOptions(OptionsResolver $resolver, string $value = null): ?Options
    {
        $connection = $resolver->connection();
        $qb         = $connection->createQueryBuilder();
        
        $options = $qb->select('`countries_id` as `value`, `countries_iso_code_2` as `text`')
            ->from('`countries`')
            ->execute()
            ->fetchAll();
        
        foreach ($options as &$option) {
            $option['text'] = $resolver->getText($option['text'], 'countries');
        }
        unset($option);
        
        usort($options,
            static function (array $a, array $b) {
                return strcmp($a['text'], $b['text']);
            });
        
        return Options::fromArray($options);
    }
    
    
    /**
     * Defines the UI's input type for current configuration type.
     *
     * @return string
     */
    public function inputType(): string
    {
        return 'dropdown';
    }
}